@@ -6,14 +6,15 @@
 #  Author: Lori Jonestrask (mintblue87@gmail.com) .
 
 
+from __future__ import absolute_import
 __all__ = ['lib_additivity_check_statistics', 'lib_curvature', 'lib_ptrm_statistics', 'lib_directional_statistics', 'lib_IZZI_MD', 'lib_arai_plot_statistics', 'lib_tail_check_statistics']
 
 #print "initializing in /lib"
-import lib_arai_plot_statistics
-import lib_curvature
-import leastsq_jacobian
-import lib_directional_statistics
-import lib_IZZI_MD
-import lib_ptrm_statistics
-import lib_tail_check_statistics
-import lib_additivity_check_statistics
+from . import lib_arai_plot_statistics
+from . import lib_curvature
+from . import leastsq_jacobian
+from . import lib_directional_statistics
+from . import lib_IZZI_MD
+from . import lib_ptrm_statistics
+from . import lib_tail_check_statistics
+from . import lib_additivity_check_statistics
